@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -18,9 +21,9 @@ import gammarer.aws_secure_frontend_web_app_cloudfront_distribution._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@gammarer/aws-frontend-web-app-deploy-stack",
-    "0.9.6",
+    "1.1.7",
     __name__[0:-6],
-    "aws-frontend-web-app-deploy-stack@0.9.6.jsii.tgz",
+    "aws-frontend-web-app-deploy-stack@1.1.7.jsii.tgz",
 )
 
 __all__ = [
